@@ -61,7 +61,8 @@ class TestParser(object):
 
     def test_single_statemet_parsing(self):
         parser = Parser()
-        with open(os.path.join(BASEPATH, "Coda_v2_3_single_statement.txt")) as f:
+        with open(os.path.join(BASEPATH,
+                               "Coda_v2_3_single_statement.txt"), 'rb') as f:
             content = f.read()
         statements = parser.parse(content)
         assert len(statements) == 1
@@ -71,7 +72,8 @@ class TestParser(object):
 
     def test_multi_statemets_parsing(self):
         parser = Parser()
-        with open(os.path.join(BASEPATH, "Coda_v2_3_multi_statements.txt")) as f:
+        with open(os.path.join(BASEPATH,
+                               "Coda_v2_3_multi_statements.txt"), 'rb') as f:
             content = f.read()
         statements = parser.parse(content)
         assert len(statements) == 2
@@ -82,7 +84,7 @@ class TestParser(object):
         eq_(movement.transaction_ref, "SWJVZ0BN6 BKTBBNPOSKZ")
         eq_(movement.transaction_amount, 20.0)
         eq_(movement.transaction_amount_sign,  AmountSign.CREDIT)
-        eq_(movement.transaction_type, "0")
+        eq_(movement.transaction_type, 0)
         eq_(movement.transaction_date, '2009-03-05')
         eq_(movement.transaction_family, "04")
         eq_(movement.transaction_code, "50")
@@ -112,26 +114,103 @@ class TestParser(object):
     def test_wrong_globalisation(self):
         """Test wrong globalisation
 
-        Check that a globalisation line without the corresponding 'end globalisation'
-        is considered as Normal
+        Check that a globalisation line without the corresponding
+        'end globalisation' is considered as Normal
         """
         parser = Parser()
-        with open(os.path.join(BASEPATH, "Coda_v2_3_faulty_globalisation.txt")) as f:
+        with open(os.path.join(
+                BASEPATH, "Coda_v2_3_faulty_globalisation.txt"), 'rb') as f:
             content = f.read()
         statements = parser.parse(content)
-        assert len(statements) == 1
+        eq_(len(statements), 1)
         statement = statements[0]
         eq_(len(statement.movements), 11)
         for mv in statement.movements:
             eq_(mv.type, MovementRecordType.NORMAL)
 
+    def test_wrong_globalisation_2(self):
+        """Test wrong globalisation
+
+        Check that a globalisation line without details
+        is considered as Normal (file contains only globalisation statemnts)
+        """
+        parser = Parser()
+        with open(os.path.join(
+                BASEPATH, "Coda_v2_3_faulty_globalisation_2.txt"), 'rb') as f:
+            content = f.read()
+        statements = parser.parse(content)
+        eq_(len(statements), 1)
+        statement = statements[0]
+        eq_(len(statement.movements), 2)
+        for mv in statement.movements:
+            eq_(mv.type, MovementRecordType.NORMAL)
+
+    def test_globalisation(self):
+        """Test that a globalisation line with details is considerd as
+        Globalisation and its details as Normal
+        """
+        parser = Parser()
+        with open(os.path.join(
+                BASEPATH, "Coda_v2_3_globalisation.txt"), 'rb') as f:
+            content = f.read()
+        statements = parser.parse(content)
+        eq_(len(statements), 1)
+        statement = statements[0]
+        eq_(len(statement.movements), 5)
+        for idx, mv in enumerate(statement.movements):
+            if idx == 2:
+                eq_(mv.type, MovementRecordType.GLOBALISATION)
+            else:
+                eq_(mv.type, MovementRecordType.NORMAL)
+        with open(os.path.join(BASEPATH,
+                               "Coda_v2_3_globalisation_2.txt"), 'rb') as f:
+            content = f.read()
+        statements = parser.parse(content)
+        assert len(statements) == 1
+        statement = statements[0]
+        eq_(len(statement.movements), 4)
+        for mv in statement.movements:
+            eq_(mv.type, MovementRecordType.NORMAL)
+
     def test_unsupported_version(self):
         parser = Parser()
-        with open(os.path.join(BASEPATH, "Coda_faulty_version.txt")) as f:
+        with open(os.path.join(
+                BASEPATH, "Coda_faulty_version.txt"), 'rb') as f:
             content = f.read()
         with assert_raises(CodaParserException) as cm:
             parser.parse(content)
         eq_(cm.exception.code, ' R001')
-        eq_(cm.exception.msg, 'CODA V5 statements are not supported, please contact your bank')
+        eq_(cm.exception.msg,
+            'CODA V5 statements are not supported, please contact your bank')
 
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
+    def test_parse_methods(self):
+        parser = Parser()
+        # test a invalid file name
+        with assert_raises(ValueError):
+            parser.parse_file('invalid_file_name')
+        # test parsing from a path to a file
+        parser = Parser()
+        file_name = os.path.join(BASEPATH, "Coda_v2_3_single_statement.txt")
+        statements = parser.parse_file(file_name)
+        eq_(len(statements), 1)
+
+        # test parsing from a file-like object
+        parser = Parser()
+        with open(os.path.join(file_name), 'rb'):
+            statements = parser.parse_file(file_name)
+            eq_(len(statements), 1)
+
+        # test parsing an invalid content
+        with assert_raises(ValueError) as cm:
+            parser.parse(b'invalid_coda_content')
+        ex = cm.exception
+        eq_(str(ex), 'The given value is not a valid coda content')
+
+    def test_foreign_account(self):
+        parser = Parser()
+        file_name = os.path.join(BASEPATH, "Coda_foreign_account.txt")
+        statements = parser.parse_file(file_name)
+        eq_(len(statements), 1)
+        st = statements[0]
+        eq_(st.acc_number, 'FR1234567890240924002304825')
+        eq_(st.currency, 'EUR')
